<?php

/**
 * About Us Page template.
 * 
 * @package ThemeStarter
 */

?>

<!-- Get Header -->
<?php get_header(); ?>

<section>

  <div class="grid md:grid-cols-2 max-w-7xl mx-auto py-8 px-4 lg:py-24 gap-4 md:gap-8">
    <div>
      <p class="max-w-lg text-stone-500">
        We are a local software development company and work with business owners like you to digitalize their processes and solve their bottlenecks and problems. We specialize in custom software, which means we can create very specific solutions for the bumps in your very particular road. Whether you'd like to speed up your processes by creating internal company tools for you, or you'd like to develop a brand new product to use in-house or sell to your clients, harpLabs can build it. We've created solutions for many industries such as Health Care, Insurance, Engineering, and IoT, just to name a few.
      </p>
    </div>
    <div class="order-first md:order-last flex items-center justify-center">
      <img class="w-3/5" src="<?php echo get_template_directory_uri(); ?>/assets/images/logos/harplabs-logo-dark.png" alt="Harplabs Inc Full Logo" />
    </div>
  </div>

</section>


<div class="relative">

  <div class="absolute inset-0">
    <img class="h-full w-full object-cover" src="https://harplabs.com/wp-content/uploads/2017/12/d3-1024x683.jpg" alt="" />
    <div class="absolute inset-0 bg-gray-500 mix-blend-multiply" aria-hidden="true"></div>
  </div>

  <div class="relative mx-auto max-w-7xl py-24 px-4 sm:py-32 sm:px-6 lg:px-8">
    <h1 class="font-bold mt-8 text-4xl text-white tracking-tight sm:text-5xl lg:text-6xl"><?php _e('We help businesses succeed in the digital and software era.', 'harplabs'); ?></h1>
  </div>

</div>

<div class="bg-white">

  <div class="lg:flex lg:justify-between lg:px-8 max-w-7xl mx-auto px-4 py-16 sm:px-6 sm:py-24">
    <div>
      <h2 class="text-4xl text-center font-bold tracking-tight text-gray-900 sm:text-5xl lg:text-6xl"><?php _e('Who we are', 'harplabs'); ?></h2>
      <img src="<?php echo esc_url(get_template_directory_uri()) . '/assets/images/bgs/technologies.jpg'; ?>" alt="">
    </div>
    <p class="mt-5 text-gray-500 text-xl lg:max-w-xl"> <?php _e('Founded in 2012 by Mina Michail, a senior developer with extensive experience in building enterprise solutions, harpLabs inc. has become a renowned provider of custom software solutions for small to large organizations.', 'harplabs'); ?><br /><br /> <?php _e('Based in Mississauga, the company has worked with over 100 clients across Canada and various industries, including medical, healthcare, finance, construction, hospitality, information technology, legal, and insurance, helping them to modernize and optimize their systems.', 'harplabs'); ?><br /><br /> <?php _e('With a track record of success and a reputation for excellence, harpLabs is a trusted partner for businesses seeking to enhance their operations through software and digital marketing.', 'harplabs'); ?> </p>
  </div>

</div>

<div class="py-12 sm:pt-16">

  <div class="px-4 sm:px-6 lg:px-8">
    <div class="mx-auto max-w-7xl text-center">
      <h2 class="text-3xl font-bold tracking-tight text-gray-900 sm:text-4xl"><?php _e('Trusted by companies in 12+ industries.', 'harplabs'); ?></h2>
      <p class="mt-3 text-xl text-gray-500 sm:mt-4"><?php _e('We have earned a reputation for delivering high quality products and services. From startups to large corporation, we can help you overcome bottlenecks and challenges.', 'harplabs'); ?></p>
      <!-- Client Grid -->
    </div>
    <?php get_template_part('template-parts/partials/client-grid'); ?>
  </div>

</div>

<div class="bg-white">

  <h2 class="text-4xl text-center font-bold tracking-tight text-gray-900 sm:text-5xl lg:text-6xl "><?php _e('Why choose us?', 'harplabs'); ?></h2>
  <div class="lg:px-8 max-w-7xl mx-auto px-4 py-16 sm:px-6">

    <div class="gap-2 grid lg:grid-cols-3 items-stretch justify-center bg-stone-100 p-4">
      <?php get_template_part('template-parts/partials/why-us-general'); ?>
    </div>

  </div>


</div>

<div class="px-4 py-8 sm:px-6 sm:py-10 lg:px-8 bg-stone-100">

  <div class="max-w-7xl mx-auto">
    <h2 id="offices-heading" class="text-3xl font-bold tracking-tight text-warm-gray-900"><?php _e('Our offices', 'harplabs'); ?></h2>
    <div class="gap-10 grid grid-cols-1 mt-10 md:grid-cols-3">
      <div>
        <h3 class="font-bold text-warm-gray-900 text-xl"><?php _e('Head Office', 'harplabs'); ?></h3>
        <p class="mt-2 text-base text-warm-gray-500"><span class="block font-medium text-gray-500"><?php _e('Suite 200, 55 Village Centre Place', 'harplabs'); ?></span> <span class="block text-gray-500"><?php _e('Mississauga, ON L4Z 1V9', 'harplabs'); ?></span></p>
      </div>
      <div>
        <h3 class="font-bold text-warm-gray-900 text-xl"><?php _e('St. John', 'harplabs'); ?></h3>
        <p class="mt-2 text-base text-warm-gray-500"><span class="block font-medium text-gray-500"><?php _e('495 Water St.', 'harplabs'); ?></span> <span class="block text-gray-500"><?php _e('St. John&apos;s, NL A1C 5X8', 'harplabs'); ?></span></p>
      </div>
    </div>
  </div>

</div>
<!-- Client Grid -->
<?php get_template_part('template-parts/partials/get-started-cta'); ?>


<!-- Get Footer -->
<?php get_footer(); ?>